#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class FtaInfraSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         FTAInfraSettingAtt
                | 
                | Represents the FT&A (Functional Tolerancing & Annotation) infrastructure
                | setting controller object.
                | Role: The FT&A infrastructure setting controller object deals with the setting
                | parameters displayed in:
                | 
                |     The Tolerancing property page for the Tolerancing Standard and the Leader
                |     Associativity setting parameters.
                |     To access this property page:
                |         Click the Options command in the Tools menu
                |         Click + left of Mechanical Design to unfold the workbench
                |         list
                |         Click Functional Tolerancing & Annotation
                |         Click Tolerancing
                |     The Display property page for the Grid Display, the Grid Snap Point, the
                |     Allow Distorsions, the Grid Primary Spacing, the Grid Secondary Step, the GridV
                |     Primary Spacing, the GridV Secondary Step, the Under Set Tree Visu, the Under
                |     View Tree Visu, and the Under Feature Tree Visu setting
                |     parameters.
                |     To access this property page:
                |         Click the Options command in the Tools menu
                |         Click + left of Mechanical Design to unfold the workbench
                |         list
                |         Click Functional Tolerancing & Annotation
                |         Click Display
                |     The Manipulators property page for the Manipulator Reference Size, the
                |     Manipulator Zoom Capability, and the Move After Creation, setting
                |     parameters.
                |     To access this property page:
                |         Click the Options command in the Tools menu
                |         Click + left of Mechanical Design to unfold the workbench
                |         list
                |         Click Functional Tolerancing & Annotation
                |         Click Manipulators
                |     The View/Annotation Plane property page for the View Associativity, the
                |     View Referential, the View Referential Zoomable, and the View Profile setting
                |     parameters.
                |     To access this property page:
                |         Click the Options command in the Tools menu
                |         Click + left of Mechanical Design to unfold the workbench
                |         list
                |         Click Functional Tolerancing & Annotation
                |         Click View/Annotation Plane
                |     The Cgr Management property page for the Save in CGR setting
                |     parameter.
                |     To access this property page:
                |         Click the Options command in the Tools menu
                |         Click + left of Infrastructure to unfold the workbench
                |         list
                |         Click Product Structure
                |         Click Cgr Management
                | 
                |     The Save in CGR setting parameter represents the state of the check button
                |     named: Save FTA 3D Annotation representation in CGR.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.fta_infra_setting_att = com_object

    @property
    def allow_distortions(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AllowDistortions() As boolean
                | 
                |     Returns or sets the Allow Distortions setting parameter
                |     value.
                |     True if the Allow Distortions setting parameter is checked and thus enables
                |     distorsions.
                |     Role: The Allow Distortions setting parameter defines whether grid spacing
                |     and graduations are the same horizontally and vertically (no distorsion) or not
                |     (distorsions enabled).

        :rtype: bool
        """

        return self.fta_infra_setting_att.AllowDistortions

    @allow_distortions.setter
    def allow_distortions(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.AllowDistortions = value

    @property
    def grid_display(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GridDisplay() As boolean
                | 
                |     Returns or sets the Grid Display setting parameter value.
                |     True if the Grid Display setting parameter is checked and thus enables the
                |     grid to be displayed.
                |     Role: The Grid Display setting parameter displays a grid on the active
                |     view.

        :rtype: bool
        """

        return self.fta_infra_setting_att.GridDisplay

    @grid_display.setter
    def grid_display(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.GridDisplay = value

    @property
    def grid_primary_spacing(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GridPrimarySpacing() As double
                | 
                |     Returns or sets the Grid Primary Spacing setting parameter
                |     value.
                |     Role: The Grid Primary Spacing setting parameter defines the horizontal
                |     spacing on the grid, expressed in millimiters. The default value is 100mm.

        :rtype: float
        """

        return self.fta_infra_setting_att.GridPrimarySpacing

    @grid_primary_spacing.setter
    def grid_primary_spacing(self, value: float):
        """
        :param float value:
        """

        self.fta_infra_setting_att.GridPrimarySpacing = value

    @property
    def grid_secondary_step(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GridSecondaryStep() As long
                | 
                |     Returns or sets the Grid Secondary Step setting parameter
                |     value.
                |     Role: The Grid Secondary Step setting parameter defines the grid's
                |     horizontal graduations. The default value is 10.

        :rtype: int
        """

        return self.fta_infra_setting_att.GridSecondaryStep

    @grid_secondary_step.setter
    def grid_secondary_step(self, value: int):
        """
        :param int value:
        """

        self.fta_infra_setting_att.GridSecondaryStep = value

    @property
    def grid_snap_point(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GridSnapPoint() As boolean
                | 
                |     Returns or sets the Grid Snap Point setting parameter
                |     value.
                |     True if the Grid Snap Point setting parameter is checked and thus enables
                |     the annotation to be snapped to the nearest grid point. Otherwise, the gris is
                |     not used to anchor the annotation.

        :rtype: bool
        """

        return self.fta_infra_setting_att.GridSnapPoint

    @grid_snap_point.setter
    def grid_snap_point(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.GridSnapPoint = value

    @property
    def grid_v_primary_spacing(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GridVPrimarySpacing() As double
                | 
                |     Returns or sets the GridV Primary Spacing setting parameter
                |     value.
                |     Role: The GridV Primary Spacing setting parameter defines the vertical
                |     spacing on the grid, expressed in millimiters. The default value is 100mm. Set
                |     this value only if distorsions are allowed thanks to the AllowDistortions
                |     property. Otherwise, the value sets to the Grid Primary Spacing setting
                |     parameter thanks to the GridPrimarySpacing for horizontal spacing is taken into
                |     account.

        :rtype: float
        """

        return self.fta_infra_setting_att.GridVPrimarySpacing

    @grid_v_primary_spacing.setter
    def grid_v_primary_spacing(self, value: float):
        """
        :param float value:
        """

        self.fta_infra_setting_att.GridVPrimarySpacing = value

    @property
    def grid_v_secondary_step(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GridVSecondaryStep() As long
                | 
                |     Returns or sets the GridV Secondary Step setting parameter
                |     value.
                |     Role: The GridV Secondary Step setting parameter defines the grid's
                |     vertical graduations. The default value is 10. Set this value only if
                |     distorsions are allowed thanks to the AllowDistortions property. Otherwise, the
                |     value sets to the Grid Secondary Step setting parameter thanks to the
                |     GridSecondaryStep for the number of horizontal graduations is taken into
                |     account.

        :rtype: int
        """

        return self.fta_infra_setting_att.GridVSecondaryStep

    @grid_v_secondary_step.setter
    def grid_v_secondary_step(self, value: int):
        """
        :param int value:
        """

        self.fta_infra_setting_att.GridVSecondaryStep = value

    @property
    def leader_associativity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LeaderAssociativity() As CATFTALeaderAssociativity
                | 
                |     Returns or sets the Leader Associativity setting parameter
                |     value.
                |     Role: The Leader Associativity setting parameter defines the associativity
                |     of a leader with the pointed geometrical element.

        :return: enum catfta_leader_associativity
        :rtype: int
        """

        return self.fta_infra_setting_att.LeaderAssociativity

    @leader_associativity.setter
    def leader_associativity(self, value: int):
        """
        :param int value: enum catfta_leader_associativity
        """

        self.fta_infra_setting_att.LeaderAssociativity = value

    @property
    def man_ref_siz(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ManRefSiz() As double
                | 
                |     Returns or sets the Manipulator Reference Size setting parameter
                |     value.
                |     Role: The Manipulator Reference Size setting parameter defines the size of
                |     the manipulator attached to the end of an annotation leader. The default value
                |     is 2mm.

        :rtype: float
        """

        return self.fta_infra_setting_att.ManRefSiz

    @man_ref_siz.setter
    def man_ref_siz(self, value: float):
        """
        :param float value:
        """

        self.fta_infra_setting_att.ManRefSiz = value

    @property
    def man_zoo_cap(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ManZooCap() As boolean
                | 
                |     Returns or sets the Manipulator Zoom Capability setting parameter
                |     value.
                |     True if the Manipulator Zoom Capability setting parameter is checked and
                |     thus enables the annotation leader end manipulator to be zoomable. Otherwise,
                |     it is not zoomable.

        :rtype: bool
        """

        return self.fta_infra_setting_att.ManZooCap

    @man_zoo_cap.setter
    def man_zoo_cap(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.ManZooCap = value

    @property
    def move_after_creation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MoveAfterCreation() As boolean
                | 
                |     Returns or sets the Move After Creation setting parameter
                |     value.
                |     True if the Move After Creation setting parameter is checked and thus
                |     enables the annotation leader end manipulator to be moved, after the annotation
                |     creation, along lines or curves that represent the intersection between the
                |     geometry and the annotation's plane. Otherwise, the annotation leader end
                |     manipulator cannot be moved.

        :rtype: bool
        """

        return self.fta_infra_setting_att.MoveAfterCreation

    @move_after_creation.setter
    def move_after_creation(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.MoveAfterCreation = value

    @property
    def save_in_cgr(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SaveInCGR() As boolean
                | 
                |     Returns or sets the Save In CGR setting parameter value.
                |     True if the Save In CGR setting parameter is checked.
                |     Role: When set to True, the FT&A 3D Annotation representations are saved in
                |     CGR. Otherwise, they are not saved.

        :rtype: bool
        """

        return self.fta_infra_setting_att.SaveInCGR

    @save_in_cgr.setter
    def save_in_cgr(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.SaveInCGR = value

    @property
    def standard(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Standard() As CATBSTR
                | 
                |     Returns or sets the Tolerancing Standard setting parameter
                |     value.
                |     Role: The Tolerancing Standard setting parameter defines the standard of
                |     the annotation's set.
                |     Legal values: five conventional standards are available:
                | 
                |         ASME: American Society for Mechanical Engineers
                |         ASME_3D: American Society for Mechanical Engineers
                |         ANSI: American National Standards Institute
                |         JIS: Japanese Industrial Standard
                |         ISO: International Organization for Standardization

        :rtype: str
        """

        return self.fta_infra_setting_att.Standard

    @standard.setter
    def standard(self, value: str):
        """
        :param str value:
        """

        self.fta_infra_setting_att.Standard = value

    @property
    def under_feature(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UnderFeature() As boolean
                | 
                |     Returns or sets the Under Geometric Feature Nodes setting parameter
                |     value.
                |     True if the Under Geometric Feature Nodes setting parameter is checked and
                |     thus enables 3D annotations to be displayed in the specification tree. This
                |     lets you view 3D annotations under the Part Design or Generative Shape Design
                |     feature nodes to which they are applied.

        :rtype: bool
        """

        return self.fta_infra_setting_att.UnderFeature

    @under_feature.setter
    def under_feature(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.UnderFeature = value

    @property
    def under_set(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UnderSet() As boolean
                | 
                |     Returns or sets the Under Annotation Set Node setting parameter
                |     value.
                |     True if the Under Annotation Set Node setting parameter is checked and thus
                |     enables 3D annotations to be displayed under the annotation set node in the
                |     specification tree. Set this parameter to True only if the Under
                |     View/Annotation Plane Nodes setting parameter managed by UnderView is set to
                |     True.

        :rtype: bool
        """

        return self.fta_infra_setting_att.UnderSet

    @under_set.setter
    def under_set(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.UnderSet = value

    @property
    def under_view(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UnderView() As boolean
                | 
                |     Returns or sets the Under View/Annotation Plane Nodes setting parameter
                |     value.
                |     True if the Under View/Annotation Plane Nodes setting parameter is checked
                |     and thus enables 3D annotations to be displayed under the view/annotation plane
                |     nodes in the specification tree. This lets you view 3D annotations under the
                |     view node to which they are linked.

        :rtype: bool
        """

        return self.fta_infra_setting_att.UnderView

    @under_view.setter
    def under_view(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.UnderView = value

    @property
    def view_associativity(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ViewAssociativity() As boolean
                | 
                |     Returns or sets the View Associativity setting parameter
                |     value.
                |     True if the View Associativity setting parameter is checked and thus
                |     enables the associativity of the view/annotation plane associativity with the
                |     pointed geometrical elements.
                |     Role: The View Associativity setting parameter defines whether the views
                |     created are associative with the geometry. When views are associative to the
                |     geometry, any modification applied to the geometry or to the axis system is
                |     reflected in the view definition.

        :rtype: bool
        """

        return self.fta_infra_setting_att.ViewAssociativity

    @view_associativity.setter
    def view_associativity(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.ViewAssociativity = value

    @property
    def view_profile(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ViewProfile() As boolean
                | 
                |     Returns or sets the View Profile setting parameter value.
                |     True if the View Profile setting parameter is checked and thus enables the
                |     view/annotation plane profile on the part/product to be displayed.

        :rtype: bool
        """

        return self.fta_infra_setting_att.ViewProfile

    @view_profile.setter
    def view_profile(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.ViewProfile = value

    @property
    def view_referential(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ViewReferential() As boolean
                | 
                |     Returns or sets the View Referential setting parameter
                |     value.
                |     True if the View Referential setting parameter is checked and thus enables
                |     the display of the active annotation plane axis system.

        :rtype: bool
        """

        return self.fta_infra_setting_att.ViewReferential

    @view_referential.setter
    def view_referential(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.ViewReferential = value

    @property
    def view_referential_zoomable(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ViewReferentialZoomable() As boolean
                | 
                |     Returns or sets the View Referential Zoomable setting parameter
                |     value.
                |     True if the View Referential Zoomable setting parameter is checked and thus
                |     enables the annotation plane axis to be zoomable.

        :rtype: bool
        """

        return self.fta_infra_setting_att.ViewReferentialZoomable

    @view_referential_zoomable.setter
    def view_referential_zoomable(self, value: bool):
        """
        :param bool value:
        """

        self.fta_infra_setting_att.ViewReferentialZoomable = value

    def get_allow_distortions_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAllowDistortionsInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Allow Distorsions setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetAllowDistortionsInfo(admin_level, o_locked)

    def get_grid_display_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGridDisplayInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Grid Display setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetGridDisplayInfo(admin_level, o_locked)

    def get_grid_primary_spacing_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGridPrimarySpacingInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Grid Primary Spacing setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetGridPrimarySpacingInfo(admin_level, o_locked)

    def get_grid_secondary_step_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGridSecondaryStepInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Grid Secondary Step setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetGridSecondaryStepInfo(admin_level, o_locked)

    def get_grid_snap_point_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGridSnapPointInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Grid Snap Point setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetGridSnapPointInfo(admin_level, o_locked)

    def get_grid_v_primary_spacing_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGridVPrimarySpacingInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the GridV Primary Spacing setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetGridVPrimarySpacingInfo(admin_level, o_locked)

    def get_grid_v_secondary_step_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetGridVSecondaryStepInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the GridV Secondary Step setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetGridVSecondaryStepInfo(admin_level, o_locked)

    def get_leader_associativity_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLeaderAssociativityInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Leader Associativity setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetLeaderAssociativityInfo(admin_level, o_locked)

    def get_man_ref_size_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetManRefSizInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Manipulator Reference Size setting
                |     parameter value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetManRefSizInfo(admin_level, o_locked)

    def get_man_zoo_cap_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetManZooCapInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Manipulator Zoom Capability setting
                |     parameter value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetManZooCapInfo(admin_level, o_locked)

    def get_move_after_creation_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMoveAfterCreationInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Move After Creation setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetMoveAfterCreationInfo(admin_level, o_locked)

    def get_save_in_cgr_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSaveInCGRInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Save In CGR setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetSaveInCGRInfo(admin_level, o_locked)

    def get_standard_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStandardInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Tolerancing Standard setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetStandardInfo(admin_level, o_locked)

    def get_under_feature_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUnderFeatureInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Under Geometric Feature Nodes setting
                |     parameter value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetUnderFeatureInfo(admin_level, o_locked)

    def get_under_set_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUnderSetInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Under Annotation Set Node setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetUnderSetInfo(admin_level, o_locked)

    def get_under_view_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUnderViewInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Under View/Annotation Plane Nodes setting
                |     parameter value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetUnderViewInfo(admin_level, o_locked)

    def get_view_associativity_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetViewAssociativityInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the View Associativity setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetViewAssociativityInfo(admin_level, o_locked)

    def get_view_profile_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetViewProfileInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the View Profile setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetViewProfileInfo(admin_level, o_locked)

    def get_view_referential_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetViewReferentialInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the View Referential setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetViewReferentialInfo(admin_level, o_locked)

    def get_view_referential_zoomable_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetViewReferentialZoomableInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the View Referential Zoomable setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.fta_infra_setting_att.GetViewReferentialZoomableInfo(admin_level, o_locked)

    def set_allow_distortions_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAllowDistortionsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Allow Distorsions setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetAllowDistortionsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_allow_distortions_lock'
        # # vba_code = """
        # # Public Function set_allow_distortions_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetAllowDistortionsLock iLocked
        # #     set_allow_distortions_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_grid_display_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGridDisplayLock(boolean iLocked)
                | 
                |     Locks or unlocks the Grid Display setting parameter value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetGridDisplayLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_grid_display_lock'
        # # vba_code = """
        # # Public Function set_grid_display_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetGridDisplayLock iLocked
        # #     set_grid_display_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_grid_primary_spacing_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGridPrimarySpacingLock(boolean iLocked)
                | 
                |     Locks or unlocks the Grid Primary Spacing setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetGridPrimarySpacingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_grid_primary_spacing_lock'
        # # vba_code = """
        # # Public Function set_grid_primary_spacing_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetGridPrimarySpacingLock iLocked
        # #     set_grid_primary_spacing_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_grid_secondary_step_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGridSecondaryStepLock(boolean iLocked)
                | 
                |     Locks or unlocks the Grid Secondary Step setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetGridSecondaryStepLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_grid_secondary_step_lock'
        # # vba_code = """
        # # Public Function set_grid_secondary_step_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetGridSecondaryStepLock iLocked
        # #     set_grid_secondary_step_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_grid_snap_point_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGridSnapPointLock(boolean iLocked)
                | 
                |     Locks or unlocks the Grid Snap Point setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetGridSnapPointLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_grid_snap_point_lock'
        # # vba_code = """
        # # Public Function set_grid_snap_point_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetGridSnapPointLock iLocked
        # #     set_grid_snap_point_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_grid_v_primary_spacing_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGridVPrimarySpacingLock(boolean iLocked)
                | 
                |     Locks or unlocks the GridV Primary Spacing setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetGridVPrimarySpacingLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_grid_v_primary_spacing_lock'
        # # vba_code = """
        # # Public Function set_grid_v_primary_spacing_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetGridVPrimarySpacingLock iLocked
        # #     set_grid_v_primary_spacing_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_grid_v_secondary_step_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetGridVSecondaryStepLock(boolean iLocked)
                | 
                |     Locks or unlocks the GridV Secondary Step setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetGridVSecondaryStepLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_grid_v_secondary_step_lock'
        # # vba_code = """
        # # Public Function set_grid_v_secondary_step_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetGridVSecondaryStepLock iLocked
        # #     set_grid_v_secondary_step_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_leader_associativity_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLeaderAssociativityLock(boolean iLocked)
                | 
                |     Locks or unlocks the Leader Associativity setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetLeaderAssociativityLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_leader_associativity_lock'
        # # vba_code = """
        # # Public Function set_leader_associativity_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetLeaderAssociativityLock iLocked
        # #     set_leader_associativity_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_man_ref_size_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetManRefSizLock(boolean iLocked)
                | 
                |     Locks or unlocks the Manipulator Reference Size setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetManRefSizLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_man_ref_siz_lock'
        # # vba_code = """
        # # Public Function set_man_ref_siz_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetManRefSizLock iLocked
        # #     set_man_ref_siz_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_man_zoo_cap_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetManZooCapLock(boolean iLocked)
                | 
                |     Locks or unlocks the Manipulator Zoom Capability setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetManZooCapLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_man_zoo_cap_lock'
        # # vba_code = """
        # # Public Function set_man_zoo_cap_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetManZooCapLock iLocked
        # #     set_man_zoo_cap_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_move_after_creation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMoveAfterCreationLock(boolean iLocked)
                | 
                |     Locks or unlocks the Move After Creation setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetMoveAfterCreationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_move_after_creation_lock'
        # # vba_code = """
        # # Public Function set_move_after_creation_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetMoveAfterCreationLock iLocked
        # #     set_move_after_creation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_save_in_cgr_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSaveInCGRLock(boolean iLocked)
                | 
                |     Locks or unlocks the Save In CGR setting parameter value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetSaveInCGRLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_save_in_cgr_lock'
        # # vba_code = """
        # # Public Function set_save_in_cgr_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetSaveInCGRLock iLocked
        # #     set_save_in_cgr_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_standard_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStandardLock(boolean iLocked)
                | 
                |     Locks or unlocks the Tolerancing Standard setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetStandardLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_standard_lock'
        # # vba_code = """
        # # Public Function set_standard_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetStandardLock iLocked
        # #     set_standard_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_under_feature_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUnderFeatureLock(boolean iLocked)
                | 
                |     Locks or unlocks the Under Geometric Feature Nodes setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetUnderFeatureLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_under_feature_lock'
        # # vba_code = """
        # # Public Function set_under_feature_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetUnderFeatureLock iLocked
        # #     set_under_feature_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_under_set_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUnderSetLock(boolean iLocked)
                | 
                |     Locks or unlocks the Under Annotation Set Node setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetUnderSetLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_under_set_lock'
        # # vba_code = """
        # # Public Function set_under_set_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetUnderSetLock iLocked
        # #     set_under_set_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_under_view_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUnderViewLock(boolean iLocked)
                | 
                |     Locks or unlocks the Under View/Annotation Plane Nodes setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetUnderViewLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_under_view_lock'
        # # vba_code = """
        # # Public Function set_under_view_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetUnderViewLock iLocked
        # #     set_under_view_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_view_associativity_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetViewAssociativityLock(boolean iLocked)
                | 
                |     Locks or unlocks the View Associativity setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetViewAssociativityLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_view_associativity_lock'
        # # vba_code = """
        # # Public Function set_view_associativity_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetViewAssociativityLock iLocked
        # #     set_view_associativity_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_view_profile_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetViewProfileLock(boolean iLocked)
                | 
                |     Locks or unlocks the View Profile setting parameter value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetViewProfileLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_view_profile_lock'
        # # vba_code = """
        # # Public Function set_view_profile_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetViewProfileLock iLocked
        # #     set_view_profile_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_view_referential_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetViewReferentialLock(boolean iLocked)
                | 
                |     Locks or unlocks the View Referential setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetViewReferentialLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_view_referential_lock'
        # # vba_code = """
        # # Public Function set_view_referential_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetViewReferentialLock iLocked
        # #     set_view_referential_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_view_referential_zoomable_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetViewReferentialZoomableLock(boolean iLocked)
                | 
                |     Locks or unlocks the View Referential Zoomable setting parameter
                |     value.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.fta_infra_setting_att.SetViewReferentialZoomableLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_view_referential_zoomable_lock'
        # # vba_code = """
        # # Public Function set_view_referential_zoomable_lock(fta_infra_setting_att)
        # #     Dim iLocked (2)
        # #     fta_infra_setting_att.SetViewReferentialZoomableLock iLocked
        # #     set_view_referential_zoomable_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'FtaInfraSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_objects import PSPListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class PSPGroupable(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspGroupable
                | 
                | Represent the Groupable object that can be grouped by Group
                | object.
                | Role: It is used to query the group object link to this
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_groupable = com_object

    @property
    def groups(self) -> PSPListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Groups() As PspListOfObjects (Read Only)
                | 
                |     Returns a list of Groups to which this object is a member.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspGroupable  
                |          Dim objArg1 As PspListOfObjects
                |          
                |           ...
                |          Set ObjArg1 = objThisIntf.Groups

        :rtype: PSPListOfObjects
        """

        return PSPListOfObjects(self.psp_groupable.Groups)

    def __repr__(self):
        return f'PSPGroupable(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.fitting_interfaces.sampled import Sampled


class Track(Sampled):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FittingInterfaces.Sampled
                |                         Track
                | 
                | The interface to access a CATIATrack.
                | Role: A CATIATrack (or track) object is an object to define motion to various
                | items (such as a product or a shuttle). These tracks can be simulated which
                | results in them to move along the defined trajectory (with a set
                | speed).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.track = com_object

    @property
    def move_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MoveMode() As DMUTrackMoveMode
                | 
                |     Returns or sets the track's movement mode. Can be speed or time based. In
                |     Speed mode, the total time is calculated based on the time need to travel the
                |     distance of the track at the given speed. In Time mode, the movement speed to
                |     calculated so that the end of the track is reached by the end of the total
                |     time. Uses enum DMUTrackMoveMode, which defined is in this interface.

        :return: enum dmu_track_move_mode
        :rtype: int
        """

        return self.track.MoveMode

    @move_mode.setter
    def move_mode(self, value: int):
        """
        :param int value: enum dmu_track_move_mode
        """

        self.track.MoveMode = value

    @property
    def speed(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Speed() As double
                | 
                |     Returns or sets the track speed. Please note that the value of the speed
                |     should be greater than zero.
                | 
                |     Example
                |         This example sets the track speed to 17.54.
                | 
                |          myTrack.Speed =  17.54

        :rtype: float
        """

        return self.track.Speed

    @speed.setter
    def speed(self, value: float):
        """
        :param float value:
        """

        self.track.Speed = value

    def get_matrix_all(self, o_matrix_all: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMatrixAll(CATSafeArrayVariant oMatrixAll)
                | 
                |     GetMatrixAll Gets the base location of the track. The sum of several
                |     internal transforms.
                | 
                |     Parameters:
                | 
                |         oMatrixAll
                |             An array of 12 doubles. A 3 by 3 rotation matrix followed by a
                |             position (x/y/z) vector, in millimeters. 
                | 
                |     Returns:
                |         S_OK if everything was succcessfull

        :param tuple o_matrix_all:
        :rtype: None
        """
        return self.track.GetMatrixAll(o_matrix_all)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_matrix_all'
        # # vba_code = """
        # # Public Function get_matrix_all(track)
        # #     Dim oMatrixAll (2)
        # #     track.GetMatrixAll oMatrixAll
        # #     get_matrix_all = oMatrixAll
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def mirror(self, i_point: tuple, i_normal: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Mirror(CATSafeArrayVariant iPoint,
                | CATSafeArrayVariant iNormal)
                | 
                |     Produces a "mirror image" of the track. Role: Determines the "mirror image"
                |     of a track. The "mirror" is a 3d plane specified by a point on the plane and
                |     the normal to the surface of the plane. The mirror calculation involves going
                |     through each shot and projecting it in the space on the other side of the
                |     mirror plane. The projection "reflects" the point perpendicularly to the
                |     plane.
                | 
                |     Parameters:
                | 
                |         iPoint
                |             A point on the plane that will be used to define the mirror.
                |             
                |         iNormal
                |             A normal to the plane that will be used to define the
                |             mirror.

        :param tuple i_point:
        :param tuple i_normal:
        :rtype: None
        """
        return self.track.Mirror(i_point, i_normal)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'mirror'
        # # vba_code = """
        # # Public Function mirror(track)
        # #     Dim iPoint (2)
        # #     track.Mirror iPoint
        # #     mirror = iPoint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def move(self, i_transform: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Move(CATSafeArrayVariant iTransfo)
                | 
                |     Moves the track a certain position.
                | 
                |     Parameters:
                | 
                |         iTransfo
                |             Specifies a relative amount to move the track.

        :param tuple i_transform:
        :rtype: None
        """
        return self.track.Move(i_transform)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'move'
        # # vba_code = """
        # # Public Function move(track)
        # #     Dim iTransfo (2)
        # #     track.Move iTransfo
        # #     move = iTransfo
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Track(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_circle import HybridShapeCircle
from pycatia.in_interfaces.reference import Reference


class HybridShapeCircleCtrPt(HybridShapeCircle):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.HybridShapeCircle
                |                             HybridShapeCircleCtrPt
                | 
                | Represents the hybrid shape circle object defined using a center and a point on
                | the circle.
                | Role: To access the data of the hybrid shape circle object.
                | 
                | This data includes:
                | 
                |     The circle center
                |     The point on the circle
                |     The surface that supports the circle
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeCircleCtrPt
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_circle_ctr_pt = com_object

    @property
    def center(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Center() As Reference
                | 
                |     Returns or sets the circle center.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves in HybShpCircleCenter the center of the
                |         HybShpCircle hybrid shape circle.
                | 
                |          Dim HybShpCircleCenter As Reference
                |          HybShpCircleCenter = HybShpCircle.Center

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle_ctr_pt.Center)

    @center.setter
    def center(self, reference_center: Reference):
        """
        :param Reference reference_center:
        """

        self.hybrid_shape_circle_ctr_pt.Center = reference_center.com_object

    @property
    def crossing_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CrossingPoint() As Reference
                | 
                |     Returns or sets the circle passing point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves the passing point of the HybShpCircle hybrid
                |         shape circle in HybShpCirclePassingPoint point.
                | 
                |          Dim HybShpCirclePassingPoint As Reference
                |          Set HybShpCirclePassingPoint = HybShpCircle.CrossingPoint

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle_ctr_pt.CrossingPoint)

    @crossing_point.setter
    def crossing_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_circle_ctr_pt.CrossingPoint = reference_point.com_object

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the circle support surface.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example:
                |         This example retrieves in HybShpCircleSupportSurf the support surface
                |         of the HybShpCircle hybrid shape circle.
                | 
                |          Dim HybShpCircleSupportSurf As Reference 
                |          HybShpCircleSupportSurf = HybShpCircle.Support

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle_ctr_pt.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_circle_ctr_pt.Support = reference_support.com_object

    def is_geodesic(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func IsGeodesic() As boolean
                | 
                |     Queries whether the circle is geodesic or not.
                | 
                |     Parameters:
                | 
                |         oGeod
                |             geodesic type : when TRUE, the circle is geodesic.

        :rtype: bool
        """
        return self.hybrid_shape_circle_ctr_pt.IsGeodesic()

    def set_geometry_on_support(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGeometryOnSupport()
                | 
                |     Sets GeometryOnSupport of circle.
                |     It puts the circle on the surface.

        :rtype: None
        """
        return self.hybrid_shape_circle_ctr_pt.SetGeometryOnSupport()

    def unset_geometry_on_support(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub UnsetGeometryOnSupport()
                | 
                |     Inactivates GeometryOnSupport of circle.
                |     Note: The circle becomes euclidean.

        :rtype: None
        """
        return self.hybrid_shape_circle_ctr_pt.UnsetGeometryOnSupport()

    def __repr__(self):
        return f'HybridShapeCircleCtrPt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class Replay(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Replay
                | 
                | The interface to access a CATIAReplay
                | 
                | Use this interface to customize the Replay object
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.replay = com_object

    def add_product_motion(self, i_product: Product) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddProductMotion(Product iProduct) As long
                | 
                |     Adds a product to be taken into account in the Replay
                |     object.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             CATIAProduct. Product to add. 
                |         oChannel
                |             Channel number.

        :param Product i_product:
        :rtype: int
        """
        return self.replay.AddProductMotion(i_product.com_object)

    def add_sample(self, i_channel: int, i_current_time: float, i_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSample(long iChannel,
                | double iCurrentTime,
                | CATSafeArrayVariant iPosition)
                | 
                |     Adds a sample(set of values) for a channel at a specific
                |     time
                | 
                |     Parameters:
                | 
                |         iChannel
                |             Channel number. 
                |         iCurrentTime
                |             Time. 
                |         iPosition
                |             Array of values to consider the the specified
                |             channel.

        :param int i_channel:
        :param float i_current_time:
        :param tuple i_position:
        :rtype: None
        """
        return self.replay.AddSample(i_channel, i_current_time, i_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_sample'
        # # vba_code = """
        # # Public Function add_sample(replay)
        # #     Dim iChannel (2)
        # #     replay.AddSample iChannel
        # #     add_sample = iChannel
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_nb_product_motion(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNbProductMotion() As long
                | 
                |     Get the number of channel related to products.
                | 
                |     Parameters:
                | 
                |         oNbChannel
                |             Number of channel associated to products.

        :rtype: int
        """
        return self.replay.GetNbProductMotion()

    def get_nb_sample(self, i_channel: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNbSample(long iChannel) As long
                | 
                |     Get the number of samples for a channel number.
                | 
                |     Parameters:
                | 
                |         iChannel
                |             Channel index. 
                |         oNbSample
                |             Number of samples.

        :param int i_channel:
        :rtype: int
        """
        return self.replay.GetNbSample(i_channel)

    def get_product(self, i_channel: int) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProduct(long iChannel) As Product
                | 
                |     Get the product for a channel.
                | 
                |     Parameters:
                | 
                |         iChannel
                |             Channel index. 
                |         oProduct
                |             Product.

        :param int i_channel:
        :rtype: Product
        """
        return Product(self.replay.GetProduct(i_channel))

    def get_sample_position(self, i_channel: int, i_sample: int, o_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSamplePosition(long iChannel,
                | long iSample,
                | CATSafeArrayVariant oPosition)
                | 
                |     Get the sample values.
                | 
                |     Parameters:
                | 
                |         iChannel
                |             Channel index. 
                |         iSample
                |             Sample index. 
                |         oPosition
                |             Array of values.

        :param int i_channel:
        :param int i_sample:
        :param tuple o_position:
        :rtype: None
        """
        return self.replay.GetSamplePosition(i_channel, i_sample, o_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_sample_position'
        # # vba_code = """
        # # Public Function get_sample_position(replay)
        # #     Dim iChannel (2)
        # #     replay.GetSamplePosition iChannel
        # #     get_sample_position = iChannel
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_sample_time(self, i_channel: int, i_sample: int) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSampleTime(long iChannel,
                | long iSample) As double
                | 
                |     Get the sample time.
                | 
                |     Parameters:
                | 
                |         iChannel
                |             Channel index. 
                |         iSample
                |             Sample index. 
                |         oTime
                |             Time value.

        :param int i_channel:
        :param int i_sample:
        :rtype: float
        """
        return self.replay.GetSampleTime(i_channel, i_sample)

    def remove_sample(self, i_channel: int, i_sample: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveSample(long iChannel,
                | long iSample)
                | 
                |     Remove a specific sample.
                | 
                |     Parameters:
                | 
                |         iChannel
                |             Channel index. 
                |         iSample
                |             Sample index.

        :param int i_channel:
        :param int i_sample:
        :rtype: None
        """
        return self.replay.RemoveSample(i_channel, i_sample)

    def __repr__(self):
        return f'Replay(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class ARCTag(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ARCTag
                | 
                | Interface representing a Tag.
                | 
                | Role: This interface is used to work with ARCTag.
                | The following code snippet can be used to obtain a Tag from a selected
                | Product
                | 
                |   Set ParentObject = CATIA.ActiveDocument.Selection.FindObject("CATIAProduct")	
                |   Set objTag = ParentObject.GetTechnologicalObject("Tag")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arc_tag = com_object

    def get_arc_tag_group(self, o_arc_tag_group: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetARCTagGroup(CATVariant oARCTagGroup)
                | 
                |     Function to get the parent ARC TagGroup of the ARC tag.
                | 
                |     Parameters:
                | 
                |         oARCTagGroup
                |             the parent ARCTagGroup. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param cat_variant o_arc_tag_group:
        :rtype: None
        """
        return self.arc_tag.GetARCTagGroup(o_arc_tag_group)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_arc_tag_group'
        # # vba_code = """
        # # Public Function get_arc_tag_group(arc_tag)
        # #     Dim oARCTagGroup (2)
        # #     arc_tag.GetARCTagGroup oARCTagGroup
        # #     get_arc_tag_group = oARCTagGroup
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_aux_axes_values(self, io_aux_axes_values_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAuxAxesValues(CATSafeArrayVariant
                | ioAuxAxesValuesList)
                | 
                |     Function to get the aux axes values associated with the ARC
                |     tag.
                | 
                |     Parameters:
                | 
                |         ioAuxAxesValuesList
                |             the aux axes values( array of double values ) associated with the
                |             ARC tag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple io_aux_axes_values_list:
        :rtype: None
        """
        return self.arc_tag.GetAuxAxesValues(io_aux_axes_values_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_aux_axes_values'
        # # vba_code = """
        # # Public Function get_aux_axes_values(arc_tag)
        # #     Dim ioAuxAxesValuesList (2)
        # #     arc_tag.GetAuxAxesValues ioAuxAxesValuesList
        # #     get_aux_axes_values = ioAuxAxesValuesList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_base_surface_normal(self, o_base_vec: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetBaseSurfaceNormal(CATSafeArrayVariant oBaseVec)
                | 
                |     Function to get the Base Surface Normal associated with the ARC
                |     tag.
                | 
                |     Parameters:
                | 
                |         oWallVec
                |             Base surface normal vector( array of 3 real values ).
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple o_base_vec:
        :rtype: None
        """
        return self.arc_tag.GetBaseSurfaceNormal(o_base_vec)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_base_surface_normal'
        # # vba_code = """
        # # Public Function get_base_surface_normal(arc_tag)
        # #     Dim oBaseVec (2)
        # #     arc_tag.GetBaseSurfaceNormal oBaseVec
        # #     get_base_surface_normal = oBaseVec
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_index(self, o_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetIndex(short oIndex)
                | 
                |     Function to get the index of the ARC tag in it's parent ARC
                |     TagGroup.
                | 
                |     Parameters:
                | 
                |         oIndex
                |             the index of the ARC tag in it's parent ARC TagGroup.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int o_index:
        :rtype: None
        """
        return self.arc_tag.GetIndex(o_index)

    def get_tag(self, o_tag: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTag(CATVariant oTag)
                | 
                |     Function to get the underlying basic Tag.
                | 
                |     Parameters:
                | 
                |         oTag
                |             the underlying basic Tag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param cat_variant o_tag:
        :rtype: None
        """
        return self.arc_tag.GetTag(o_tag)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_tag'
        # # vba_code = """
        # # Public Function get_tag(arc_tag)
        # #     Dim oTag (2)
        # #     arc_tag.GetTag oTag
        # #     get_tag = oTag
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_tag_param(self, i_param_name: str, o_val: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTagParam(CATBSTR iParamName,
                | double oVal)
                | 
                |     Function to get the value of a given ARC tag parameter.
                | 
                |     Parameters:
                | 
                |         iParamName
                |             the name of the ARC tag parameter. Values of following ARC tag
                |             parameters can be gotten: "WireAngle", "FlareAngle", "RakeAngle",
                |             "WireRollAngle", "BaseTangentOffset", "WallTangentOffset", "ShiftDistance",
                |             "FlareLength", "StickOut", "TCPStickOut", "NearDistance"
                |             
                |         oVal
                |             the value of the ARC tag parameter. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str i_param_name:
        :param float o_val:
        :rtype: None
        """
        return self.arc_tag.GetTagParam(i_param_name, o_val)

    def get_wall_surface_normal(self, o_wall_vec: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetWallSurfaceNormal(CATSafeArrayVariant oWallVec)
                | 
                |     Function to get the Wall Surface Normal associated with the ARC
                |     tag.
                | 
                |     Parameters:
                | 
                |         oWallVec
                |             Wall surface normal vector( array of 3 real values ).
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple o_wall_vec:
        :rtype: None
        """
        return self.arc_tag.GetWallSurfaceNormal(o_wall_vec)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_wall_surface_normal'
        # # vba_code = """
        # # Public Function get_wall_surface_normal(arc_tag)
        # #     Dim oWallVec (2)
        # #     arc_tag.GetWallSurfaceNormal oWallVec
        # #     get_wall_surface_normal = oWallVec
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_weld_geometry(self, b_status: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetWeldGeometry(short bStatus)
                | 
                |     Function to find whether wall/base normals are available for the ARC
                |     tag.
                | 
                |     Parameters:
                | 
                |         bStatus
                |             Boolean flag indicating whether wall/base normals are set for the
                |             ARC tag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int b_status:
        :rtype: None
        """
        return self.arc_tag.GetWeldGeometry(b_status)

    def rotate(self, i_angle: float, i_dir_vector: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Rotate(double iAngle,
                | CATSafeArrayVariant iDirVector)
                | 
                |     Function to Rotate the ARC tag about a given direction vector as the axis
                |     of rotation.
                | 
                |     Parameters:
                | 
                |         iAngle
                |             the angle by which the ARC tag should be rotated about the given
                |             direction vector as the axis of rotation. 
                |         iDirVector
                |             the given direction vector( array of 3 real values; axis of
                |             rotation ) about which the ARC tag has to be rotated.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param float i_angle:
        :param tuple i_dir_vector:
        :rtype: None
        """
        return self.arc_tag.Rotate(i_angle, i_dir_vector)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'rotate'
        # # vba_code = """
        # # Public Function rotate(arc_tag)
        # #     Dim iAngle (2)
        # #     arc_tag.Rotate iAngle
        # #     rotate = iAngle
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def rotate_x(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RotateX(double iAngle)
                | 
                |     Function to rotate the ARC tag about it's x-axis.
                | 
                |     Parameters:
                | 
                |         iAngle
                |             the angle by which the ARC tag should be rotated about it's x-axis.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param float i_angle:
        :rtype: None
        """
        return self.arc_tag.RotateX(i_angle)

    def rotate_y(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RotateY(double iAngle)
                | 
                |     Function to rotate the ARC tag about it's y-axis.
                | 
                |     Parameters:
                | 
                |         iAngle
                |             the angle by which the ARC tag should be rotated about it's y-axis.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param float i_angle:
        :rtype: None
        """
        return self.arc_tag.RotateY(i_angle)

    def rotate_z(self, i_angle: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RotateZ(double iAngle)
                | 
                |     Function to rotate the ARC tag about it's z-axis.
                | 
                |     Parameters:
                | 
                |         iAngle
                |             the angle by which the ARC tag should be rotated about it's z-axis.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param float i_angle:
        :rtype: None
        """
        return self.arc_tag.RotateZ(i_angle)

    def set_base_surface_normal(self, i_base_vec: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBaseSurfaceNormal(CATSafeArrayVariant iBaseVec)
                | 
                |     Function to set the Base Surface Normal associated with the ARC
                |     tag.
                | 
                |     Parameters:
                | 
                |         iBaseVec
                |             Base surface normal vector( array of 3 real values ).
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple i_base_vec:
        :rtype: None
        """
        return self.arc_tag.SetBaseSurfaceNormal(i_base_vec)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_base_surface_normal'
        # # vba_code = """
        # # Public Function set_base_surface_normal(arc_tag)
        # #     Dim iBaseVec (2)
        # #     arc_tag.SetBaseSurfaceNormal iBaseVec
        # #     set_base_surface_normal = iBaseVec
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tag_param(self, i_param_name: str, i_val: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTagParam(CATBSTR iParamName,
                | double iVal)
                | 
                |     Function to set the value of a given ARC tag parameter.
                | 
                |     Parameters:
                | 
                |         iParamName
                |             the name of the ARC tag parameter. Following ARC tag parameters can
                |             be set: "WireAngle", "FlareAngle", "RakeAngle", "WireRollAngle",
                |             "BaseTangentOffset", "WallTangentOffset", "ShiftDistance", "FlareLength",
                |             "StickOut", "TCPStickOut", "NearDistance" 
                |         iVal
                |             the value of the ARC tag parameter. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param str i_param_name:
        :param float i_val:
        :rtype: None
        """
        return self.arc_tag.SetTagParam(i_param_name, i_val)

    def set_wall_surface_normal(self, i_wall_vec: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWallSurfaceNormal(CATSafeArrayVariant iWallVec)
                | 
                |     Function to set the Wall Surface Normal associated with the ARC
                |     tag.
                | 
                |     Parameters:
                | 
                |         iWallVec
                |             Wall surface normal vector( array of 3 real values ).
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param tuple i_wall_vec:
        :rtype: None
        """
        return self.arc_tag.SetWallSurfaceNormal(i_wall_vec)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_wall_surface_normal'
        # # vba_code = """
        # # Public Function set_wall_surface_normal(arc_tag)
        # #     Dim iWallVec (2)
        # #     arc_tag.SetWallSurfaceNormal iWallVec
        # #     set_wall_surface_normal = iWallVec
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_weld_geometry(self, b_status: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWeldGeometry(short bStatus)
                | 
                |     Function to set the flag for the availability of wall/base normals for the
                |     ARC tag.
                | 
                |     Parameters:
                | 
                |         bStatus
                |             Boolean flag indicating whether wall/base normals should be
                |             available for the ARC tag. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param int b_status:
        :rtype: None
        """
        return self.arc_tag.SetWeldGeometry(b_status)

    def translate(self, i_distance: float, i_dir_vector: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Translate(double iDistance,
                | CATSafeArrayVariant iDirVector)
                | 
                |     Function to translate the ARC tag along a given direction
                |     vector.
                | 
                |     Parameters:
                | 
                |         iDistance
                |             the distance by which the ARC tag should be translated along the
                |             given direction vector. 
                |         iDirVector
                |             the given direction vector( array of 3 real values ) along which
                |             the ARC tag has to be translated. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param float i_distance:
        :param tuple i_dir_vector:
        :rtype: None
        """
        return self.arc_tag.Translate(i_distance, i_dir_vector)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'translate'
        # # vba_code = """
        # # Public Function translate(arc_tag)
        # #     Dim iDistance (2)
        # #     arc_tag.Translate iDistance
        # #     translate = iDistance
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def translate_along_seam(self, i_distance: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub TranslateAlongSeam(double iDistance)
                | 
                |     Function to translate the ARC tag along the seam.
                | 
                |     Parameters:
                | 
                |         iDistance
                |             the distance by which the ARC tag should be translated along the
                |             seam. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise.

        :param float i_distance:
        :rtype: None
        """
        return self.arc_tag.TranslateAlongSeam(i_distance)

    def __repr__(self):
        return f'ARCTag(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class SimTraceSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         SimTraceSettingAtt
                | 
                | Interface to handle parameters of Infrastructure-DELMIA
                | Infrastructure-Simulation Trace Tools Options Tab page.
                | Role: This interface is implemented by a component which represents the
                | controller of Simulation Trace Tools Options parameter
                | settings.
                | 
                |     Methods to set value of each parameter xxx
                |     Methods to get value of each parameter xxx
                |     Methods to get information on each parameter xxx
                |     Methods to lock/unlock value of each parameter xxx
                | 
                | Here is the list of parameters to use and their meaning:
                | 
                |     TracePointVisu: defines the option for displaying the points within a
                |     simulation trace.
                |     TracePointColor: defines the color to be used if displaying points within a
                |     simulation trace.
                |     TracePointSymbol: defines the symbol to be used if displaying points within
                |     a simulation trace.
                |     TraceLineVisu: defines the option for displaying the lines within a
                |     simulation trace.
                |     TraceLineColor: defines the color to be used if displaying lines within a
                |     simulation trace.
                |     TraceLineType: defines the line type to be used if displaying lines within
                |     a simulation trace.
                |     TraceLineThick: defines the thickness to be used if displaying lines within
                |     a simulation trace.
                |     TraceAxisVisu: defines the option for displaying the axis within a
                |     simulation trace.
                |     TraceAxisColor: defines the color to be used if displaying axis within a
                |     simulation trace.
                |     TraceAxisType: defines the line type to be used if displaying axis within a
                |     simulation trace.
                |     TraceAxisThick: defines the thickness to be used if displaying axis within
                |     a simulation trace.
                |     TraceDeletePath: defines the option for deleting the simulation trace when
                |     a new simulation is run.
                |     TraceLegend: defines the type of information to be displayed when a
                |     point/line/axis within a simulation trace is (pre)selected by the user. The
                |     values are in order:
                |         All Legend (not used).
                |         Name.
                |         X.
                |         Y.
                |         Z.
                |         Yaw.
                |         Pitch.
                |         Roll.
                |         Cycle Time.
                |         Show Legend.
                |         Always Visible (not used).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sim_trace_setting_att = com_object

    def get_trace_axis_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceAxisColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceAxisColor
                |     parameter.
                |     Role:Retrieves the state of the TraceAxisColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceAxisColorInfo(io_admin_level, io_locked)

    def get_trace_axis_thick_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceAxisThickInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceAxisThick
                |     parameter.
                |     Role:Retrieves the state of the TraceAxisThick parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceAxisThickInfo(io_admin_level, io_locked)

    def get_trace_axis_type_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceAxisTypeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceAxisType
                |     parameter.
                |     Role:Retrieves the state of the TraceAxisType parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceAxisTypeInfo(io_admin_level, io_locked)

    def get_trace_axis_visu_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceAxisVisuInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceAxisVisu
                |     parameter.
                |     Role:Retrieves the state of the TraceAxisVisu parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceAxisVisuInfo(io_admin_level, io_locked)

    def get_trace_delete_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceDeletePathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceDeletePath
                |     parameter.
                |     Role:Retrieves the state of the TraceDeletePath parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceDeletePathInfo(io_admin_level, io_locked)

    def get_trace_legend_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceLegendInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceLegend
                |     parameter.
                |     Role:Retrieves the state of the TraceLegend parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceLegendInfo(io_admin_level, io_locked)

    def get_trace_line_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceLineColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceLineColor
                |     parameter.
                |     Role:Retrieves the state of the TraceLineColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceLineColorInfo(io_admin_level, io_locked)

    def get_trace_line_thick_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceLineThickInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceLineThick
                |     parameter.
                |     Role:Retrieves the state of the TraceLineThick parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceLineThickInfo(io_admin_level, io_locked)

    def get_trace_line_type_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceLineTypeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceLineType
                |     parameter.
                |     Role:Retrieves the state of the TraceLineType parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceLineTypeInfo(io_admin_level, io_locked)

    def get_trace_line_visu_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTraceLineVisuInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TraceLineVisu
                |     parameter.
                |     Role:Retrieves the state of the TraceLineVisu parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTraceLineVisuInfo(io_admin_level, io_locked)

    def get_trace_point_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTracePointColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TracePointColor
                |     parameter.
                |     Role:Retrieves the state of the TracePointColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTracePointColorInfo(io_admin_level, io_locked)

    def get_trace_point_symbol_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTracePointSymbolInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TracePointSymbol
                |     parameter.
                |     Role:Retrieves the state of the TracePointSymbol parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTracePointSymbolInfo(io_admin_level, io_locked)

    def get_trace_point_visu_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTracePointVisuInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TracePointVisu
                |     parameter.
                |     Role:Retrieves the state of the TracePointVisu parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.sim_trace_setting_att.GetTracePointVisuInfo(io_admin_level, io_locked)

    def set_trace_axis_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceAxisColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceAxisColor parameter.
                |     Role:Locks or unlocks the TraceAxisColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceAxisColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_axis_color_lock'
        # # vba_code = """
        # # Public Function set_trace_axis_color_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceAxisColorLock iLocked
        # #     set_trace_axis_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_axis_thick_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceAxisThickLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceAxisThick parameter.
                |     Role:Locks or unlocks the TraceAxisThick parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceAxisThickLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_axis_thick_lock'
        # # vba_code = """
        # # Public Function set_trace_axis_thick_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceAxisThickLock iLocked
        # #     set_trace_axis_thick_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_axis_type_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceAxisTypeLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceAxisType parameter.
                |     Role:Locks or unlocks the TraceAxisType parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceAxisTypeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_axis_type_lock'
        # # vba_code = """
        # # Public Function set_trace_axis_type_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceAxisTypeLock iLocked
        # #     set_trace_axis_type_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_axis_visu_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceAxisVisuLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceAxisVisu parameter.
                |     Role:Locks or unlocks the TraceAxisVisu parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceAxisVisuLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_axis_visu_lock'
        # # vba_code = """
        # # Public Function set_trace_axis_visu_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceAxisVisuLock iLocked
        # #     set_trace_axis_visu_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_delete_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceDeletePathLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceDeletePath parameter.
                |     Role:Locks or unlocks the TraceDeletePath parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceDeletePathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_delete_path_lock'
        # # vba_code = """
        # # Public Function set_trace_delete_path_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceDeletePathLock iLocked
        # #     set_trace_delete_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_legend_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceLegendLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceLegend parameter.
                |     Role:Locks or unlocks the TraceLegend parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceLegendLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_legend_lock'
        # # vba_code = """
        # # Public Function set_trace_legend_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceLegendLock iLocked
        # #     set_trace_legend_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_line_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceLineColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceLineColor parameter.
                |     Role:Locks or unlocks the TraceLineColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceLineColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_line_color_lock'
        # # vba_code = """
        # # Public Function set_trace_line_color_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceLineColorLock iLocked
        # #     set_trace_line_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_line_thick_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceLineThickLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceLineThick parameter.
                |     Role:Locks or unlocks the TraceLineThick parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceLineThickLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_line_thick_lock'
        # # vba_code = """
        # # Public Function set_trace_line_thick_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceLineThickLock iLocked
        # #     set_trace_line_thick_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_line_type_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceLineTypeLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceLineType parameter.
                |     Role:Locks or unlocks the TraceLineType parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceLineTypeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_line_type_lock'
        # # vba_code = """
        # # Public Function set_trace_line_type_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceLineTypeLock iLocked
        # #     set_trace_line_type_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_line_visu_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTraceLineVisuLock(boolean iLocked)
                | 
                |     Locks or unlocks the TraceLineVisu parameter.
                |     Role:Locks or unlocks the TraceLineVisu parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTraceLineVisuLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_line_visu_lock'
        # # vba_code = """
        # # Public Function set_trace_line_visu_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTraceLineVisuLock iLocked
        # #     set_trace_line_visu_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_point_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTracePointColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the TracePointColor parameter.
                |     Role:Locks or unlocks the TracePointColor parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTracePointColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_point_color_lock'
        # # vba_code = """
        # # Public Function set_trace_point_color_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTracePointColorLock iLocked
        # #     set_trace_point_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_point_symbol_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTracePointSymbolLock(boolean iLocked)
                | 
                |     Locks or unlocks the TracePointSymbol parameter.
                |     Role:Locks or unlocks the TracePointSymbol parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTracePointSymbolLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_point_symbol_lock'
        # # vba_code = """
        # # Public Function set_trace_point_symbol_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTracePointSymbolLock iLocked
        # #     set_trace_point_symbol_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_trace_point_visu_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTracePointVisuLock(boolean iLocked)
                | 
                |     Locks or unlocks the TracePointVisu parameter.
                |     Role:Locks or unlocks the TracePointVisu parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.sim_trace_setting_att.SetTracePointVisuLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_trace_point_visu_lock'
        # # vba_code = """
        # # Public Function set_trace_point_visu_lock(sim_trace_setting_att)
        # #     Dim iLocked (2)
        # #     sim_trace_setting_att.SetTracePointVisuLock iLocked
        # #     set_trace_point_visu_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SimTraceSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPObject(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspObject
                | 
                | Represents PspObject.
                | Role: To access Plant Ship object information.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_object = com_object

    @property
    def application_id(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplicationID() As CatPspIDLApplicationID (Read
                | Only)
                | 
                |     Returns the ApplicationID of the object.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspObject
                |          Dim eApplID As CatPSPIDLApplicationID
                |           ...
                |          eApplID = objThisIntf.ApplicationID

        :return: enum cat_psp_idl_application_id
        :rtype: int
        """

        return self.psp_object.ApplicationID

    @property
    def domain_id(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DomainID() As CatPspIDLDomainID (Read Only)
                | 
                |     Returns the DomainID of the object.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspObject
                |          Dim eDomanID As CatPspIDLDomainID
                |           ...
                |          eDomanID = objThisIntf.DomainID

        :return: enum cat_psp_idl_domain_id
        :rtype: int
        """

        return self.psp_object.DomainID

    @property
    def startup_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartupType() As CATBSTR (Read Only)
                | 
                |     Returns the Startup type of the object.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspObject
                |          Dim strStartUp As String
                |          ...
                |          strStartUp = objThisIntf.StartupType

        :rtype: str
        """

        return self.psp_object.StartupType

    def __repr__(self):
        return f'PSPObject(name="{self.name}")'
